<?php
/**
 * Adore Themes Customizer
 *
 * @package Current News
 *
 * Recent Posts Section
 */

$wp_customize->add_section(
	'current_news_recent_posts_section',
	array(
		'title'    => esc_html__( 'Recent Posts Section', 'current-news' ),
		'panel'    => 'current_news_frontpage_panel',
		'priority' => 30
	)
);

// Recent Posts section enable settings.
$wp_customize->add_setting(
	'current_news_recent_posts_section_enable',
	array(
		'default'           => false,
		'sanitize_callback' => 'current_news_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Current_News_Toggle_Checkbox_Custom_control(
		$wp_customize,
		'current_news_recent_posts_section_enable',
		array(
			'label'    => esc_html__( 'Enable Recent Posts Section', 'current-news' ),
			'type'     => 'checkbox',
			'settings' => 'current_news_recent_posts_section_enable',
			'section'  => 'current_news_recent_posts_section',
		)
	)
);

// Recent Posts title settings.
$wp_customize->add_setting(
	'current_news_recent_posts_title',
	array(
		'default'           => __( 'Recent Articles', 'current-news' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'current_news_recent_posts_title',
	array(
		'label'           => esc_html__( 'Title', 'current-news' ),
		'section'         => 'current_news_recent_posts_section',
		'active_callback' => 'current_news_if_recent_posts_enabled',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'current_news_recent_posts_title',
		array(
			'selector'            => '.recentpost h3.widget-title',
			'settings'            => 'current_news_recent_posts_title',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'current_news_recent_posts_title_text_partial',
		)
	);
}

// View All button label setting.
$wp_customize->add_setting(
	'current_news_recent_posts_view_all_button_label',
	array(
		'default'           => __( 'View All', 'current-news' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'current_news_recent_posts_view_all_button_label',
	array(
		'label'           => esc_html__( 'View All Button Label', 'current-news' ),
		'section'         => 'current_news_recent_posts_section',
		'settings'        => 'current_news_recent_posts_view_all_button_label',
		'type'            => 'text',
		'active_callback' => 'current_news_if_recent_posts_enabled',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'current_news_recent_posts_view_all_button_label',
		array(
			'selector'            => '.recentpost .adore-view-all',
			'settings'            => 'current_news_recent_posts_view_all_button_label',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'current_news_recent_posts_view_all_btn_partial',
		)
	);
}

// View All button URL setting.
$wp_customize->add_setting(
	'current_news_recent_posts_view_all_button_url',
	array(
		'default'           => '#',
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'current_news_recent_posts_view_all_button_url',
	array(
		'label'           => esc_html__( 'View All Button Link', 'current-news' ),
		'section'         => 'current_news_recent_posts_section',
		'settings'        => 'current_news_recent_posts_view_all_button_url',
		'type'            => 'url',
		'active_callback' => 'current_news_if_recent_posts_enabled',
	)
);

// recent_posts content type settings.
$wp_customize->add_setting(
	'current_news_recent_posts_content_type',
	array(
		'default'           => 'post',
		'sanitize_callback' => 'current_news_sanitize_select',
	)
);

$wp_customize->add_control(
	'current_news_recent_posts_content_type',
	array(
		'label'           => esc_html__( 'Content type:', 'current-news' ),
		'description'     => esc_html__( 'Choose where you want to render the content from.', 'current-news' ),
		'section'         => 'current_news_recent_posts_section',
		'type'            => 'select',
		'active_callback' => 'current_news_if_recent_posts_enabled',
		'choices'         => array(
			'post'   => esc_html__( 'Post', 'current-news' ),
			'recent' => esc_html__( 'Recent', 'current-news' ),
		),
	)
);

for ( $i = 1; $i <= 3; $i++ ) {
	// recent_posts post setting.
	$wp_customize->add_setting(
		'current_news_recent_posts_post_' . $i,
		array(
			'sanitize_callback' => 'current_news_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'current_news_recent_posts_post_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Post %d', 'current-news' ), $i ),
			'section'         => 'current_news_recent_posts_section',
			'type'            => 'select',
			'choices'         => current_news_get_post_choices(),
			'active_callback' => 'current_news_recent_posts_section_content_type_post_enabled',
		)
	);
}

/*========================Active Callback==============================*/
function current_news_if_recent_posts_enabled( $control ) {
	return $control->manager->get_setting( 'current_news_recent_posts_section_enable' )->value();
}
function current_news_recent_posts_section_content_type_post_enabled( $control ) {
	$content_type = $control->manager->get_setting( 'current_news_recent_posts_content_type' )->value();
	return current_news_if_recent_posts_enabled( $control ) && ( 'post' === $content_type );
}

/*========================Partial Refresh==============================*/
if ( ! function_exists( 'current_news_recent_posts_title_text_partial' ) ) :
	// Title.
	function current_news_recent_posts_title_text_partial() {
		return esc_html( get_theme_mod( 'current_news_recent_posts_title' ) );
	}
endif;
if ( ! function_exists( 'current_news_recent_posts_view_all_btn_partial' ) ) :
	// View All Btn.
	function current_news_recent_posts_view_all_btn_partial() {
		return esc_html( get_theme_mod( 'current_news_recent_posts_view_all_button_label' ) );
	}
endif;
